==> streamtuner-0.99.tar.gz: streamtuner-0.99/src/streamtuner/st-preferences-dialog.h <==
/*
 * Copyright (c) 2003, 2004 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _ST_PREFERENCES_DIALOG_H
#define _ST_PREFERENCES_DIALOG_H

#include <gtk/gtk.h>
#include "sgtk-dialog.h"

#define ST_TYPE_PREFERENCES_DIALOG		(st_preferences_dialog_get_type())
#define ST_PREFERENCES_DIALOG(obj)		(G_TYPE_CHECK_INSTANCE_CAST((obj), ST_TYPE_PREFERENCES_DIALOG, STPreferencesDialog))
#define ST_PREFERENCES_DIALOG_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST((klass), ST_TYPE_PREFERENCES_DIALOG, STPreferencesDialogClass))
#define ST_IS_PREFERENCES_DIALOG(obj)		(G_TYPE_CHECK_INSTANCE_TYPE((obj), ST_TYPE_PREFERENCES_DIALOG))
#define ST_IS_PREFERENCES_DIALOG_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), ST_TYPE_PREFERENCES_DIALOG))
#define ST_PREFERENCES_DIALOG_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), ST_TYPE_PREFERENCES_DIALOG, STPreferencesDialogClass))

typedef struct _STPreferencesDialogPrivate STPreferencesDialogPrivate;

typedef struct
{
  sGtkDialog			dialog;

  STPreferencesDialogPrivate	*priv;
} STPreferencesDialog;

typedef  struct
{
  sGtkDialogClass		parent_class;
} STPreferencesDialogClass;

GType		st_preferences_dialog_get_type	(void);
GtkWidget	*st_preferences_dialog_new	(GtkWindow *parent);

#endif /* _ST_PREFERENCES_DIALOG_H */

==> streamtuner_0.99.99.orig.tar.gz: streamtuner-0.99.99/src/streamtuner/st-preferences-dialog.h <==
/*
 * Copyright (c) 2003, 2004 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _ST_PREFERENCES_DIALOG_H
#define _ST_PREFERENCES_DIALOG_H

#include <gtk/gtk.h>
#include "sgtk-dialog.h"
#include "st-handler-api.h"

#define ST_TYPE_PREFERENCES_DIALOG		(st_preferences_dialog_get_type())
#define ST_PREFERENCES_DIALOG(obj)		(G_TYPE_CHECK_INSTANCE_CAST((obj), ST_TYPE_PREFERENCES_DIALOG, STPreferencesDialog))
#define ST_PREFERENCES_DIALOG_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST((klass), ST_TYPE_PREFERENCES_DIALOG, STPreferencesDialogClass))
#define ST_IS_PREFERENCES_DIALOG(obj)		(G_TYPE_CHECK_INSTANCE_TYPE((obj), ST_TYPE_PREFERENCES_DIALOG))
#define ST_IS_PREFERENCES_DIALOG_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), ST_TYPE_PREFERENCES_DIALOG))
#define ST_PREFERENCES_DIALOG_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), ST_TYPE_PREFERENCES_DIALOG, STPreferencesDialogClass))

typedef struct _STPreferencesDialogPrivate STPreferencesDialogPrivate;

typedef struct
{
  sGtkDialog			dialog;

  STPreferencesDialogPrivate	*priv;
} STPreferencesDialog;

typedef  struct
{
  sGtkDialogClass		parent_class;
} STPreferencesDialogClass;

GType		st_preferences_dialog_get_type	(void);
GtkWidget	*st_preferences_dialog_new	(GtkWindow *parent);
void		st_preferences_dialog_select_handler (STPreferencesDialog *dialog,
						      STHandler           *handler);

#endif /* _ST_PREFERENCES_DIALOG_H */
